.TH XRIT2RAW 1
.SH NAME
xrit2raw \- converts \fBXRIT\fP files (LRIT/HRIT = Low or High Rate Information Transmission Format) into \fBRAW\fP files (extension .raw)
.SH DOWNLOAD
http://www-loa.univ-lille1.fr/~ducos/public/xrit/xrit-0.2.3.tar.gz
.SH RELATED PAGES
http://www-loa.univ-lille1.fr/~ducos/public/xrit/put_xrit_segments_together.html

.SH SYNOPSIS
.B xrit2raw [OPTIONS] \fIxrit_file\fP [\fIoutput_raw_file\fP]
.SH DESCRIPTION
.PP
converts a \fBHRIT_CYCLE\fP file into a \fBraw\fP file.
.PP
\fBHRIT_CYCLE\fP files have the following name convention : H-000-MSGn__-MSG1________-XXXXXX___-CYCLE____-YYYYMMDDhhmm
(such files can be created with the tool put_xrit_segments_together.pl provided by the xrit2raw package, if you receive
the MSG XRIT data segments from antenna. Look at the put_xrit_segments_together.pl in-line help for more details)
.PP
(XXXXXX is the name of an \fBMSG\fP channel, such as IR016, VIS006, etc., while YYYYMMDDhhmm is the time of
acquisition, MSGn can be MSG1 or MSG2)
.PP
The \fBXRIT\fP format is one of the numerous formats in which \fBMSG\fP (\fBMETEOSAT SECOND GENERATION\fP) data
are provided. In order to let the user read easily the content of such files without bothering with a
new format, \fBxrit2raw\fP converts it into a simple raw file (a simple binary array of values with no header).
.PP
The generated .raw file will contain a raw array of 3712x3712 values of radiances (for MSG low resolution channels) or
11136x11136 values (for the MSG high resolution channel) in a user-chosen data type (see options below).
.PP
By default, the tool extracts the numeric counts (16 bits) available in the file. If you want the data in physical units,
use one of the options -f (float) or -d (double). The data will then be in mW.m^-2.sr^-1.(cm^-1)^-1
.PP
For more information on the conversion from numeric counts to physical values, please refer to 
MSG Level 1.5 Image Data Format Description, p 17 (v5A, 22 august 2007), available here (at the time of this writing):
.PP
http://www.eumetsat.int/Home/Main/Documentation/Technical_and_Scientific_Documentation/Technical_Notes/SP_1124282611560?l=en
.PP
Example :
To dump the data from a HRIT_CYCLE file (*) into a raw file (easy to read programmatically, see below), just do :
.PP
xrit2raw -F -999. -v -f H-000-MSG1__-MSG1________-VIS006___-CYCLE____-200608011200-__
.PP
This command will create a file with the same name but the extension .raw
.PP
The .raw file contains a single array of 3712x3712 values of radiances (for low resolution channels)
or 11136x11136 values (for HRV, the High Resolution Channel).
.PP
In this example the values are 32-bit float (real simple precision) since the flag -f has been used. You can also produce data 
in double precision with the -d option ; by default the original 16-bit unsigned numeric counts (proportionnal to radiances) will be retrieved.
.PP
The verbose flag -v will let you see the dimensions and the data type of the array that you've built, if you don't know it.
.PP
The option -F -999. will force xrit2raw to fill the background pixels with -999. (the default is NaN).
.PP
.PP
The raw file can easily be viewed with raw data viewers like Msphinx ( http://www-loa.univ-lille1.fr/Msphinx/ ), or
read in C with a simple fread call (or in Fortran, but be aware that there is no record mark before and after
the array, so avoid access='sequential' and prefer the parameter access='direct' in the read call)
.PP
(*) see http://www-loa.univ-lille1.fr/~ducos/public/xrit/put_xrit_segments_together.html to understand how to build a HRIT_CYCLE file
from EUMETCAST broadcast data.

.SH OPTIONS
.TP
.B -P \fIprologue_file\fP
saves the XRIT prologue into the \fBraw\fP file \fIprologue_file\fP (readable with the auxiliary tool read_seviri_prologue provided by this suite)
.TP
.B -I
displays some informations from the input file, namely the central longitude of the satellite and
the calibration coefficients (no raw file will be created)
.TP
.B -n \fIsegment\fP
extracts only one segment of 464 rows (between 1 and 8) (experimental, should not be used by most end-users)

.TP
.B -s
stores \fBMSG\fP counts (short integer) into the \fBraw\fP file (default behavior)

.TP
.B -f
stores \fBMSG\fP calibrated data as \fBfloat\fP into the \fBraw\fP file

.TP
.B -d
stores \fBMSG\fP calibrated data as \fBdouble\fP into the \fBraw\fP file

.TP
.B -v
displays the data type and dimensions of the raw array produced (directly readable in C, or
in Fortran but with no record mark, that is to say, NOT in sequential access). 
Should always be used interactively. 

.TP
.B -F \fIfill_value\fP
sets the default value, when no measure is available (for calibrated data only, not for integral counts), nan by default.
For instance, use -F -999. to set the fill value to -999. (if the IEEE Not a Number default value is an issue)

.SH COPYRIGHT
\fBxrit2raw\fP is Copyright (c) LOA/ICARE 2006-2010
.PP
This program is free software; you can redistribute it and/or modify
it under the terms of the GNU Lesser General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

.PP
This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Lesser General Public License for more details.

.PP
You should have received a copy of the GNU Lesser General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

.PP
Please report any bug or issue you could find to fabrice.ducos@univ-lille1.fr
.SH AUTHORS
Fabrice Ducos
